.\" $Id: vcsstats.man,v 1.6 2012/08/14 21:21:51 ksb Exp $
.\" $Source: /usr/msrc/usr/local/libexec/vcsstats/RCS/vcsstats.man,v $
.\" by Kevin Braunsdorf
.\" $Compile: Display%h
.\" $Display: ${nroff-groff} -Tascii -man %f | ${PAGER:-less}
.\" $Install: %b -mDeinstall %o %f && cp %f $DESTDIR/usr/local/man/man8/vcsstats.8
.\" $Deinstall: ${rm-rm} -f $DESTDIR/usr/local/man/[cm]a[nt]8/vcsstats.8*
.TH VCSSTATS 8L LOCAL
.SH NAME
vcsstats \- report Veritas failover status to PEG
.SH SYNOPSIS
.ds PN "vcsstats
\fI\*(PN\fP [\fB\-lx\fP] [\fB\-N\fP\~\fInode\fP] [\fB\-t\fP\~\fItarget\fP] [\fB\-a\fP | \fB\-s\fP\~\fIsystem\fP] [\fIgroups\fP]
.br
\fI\*(PN\fP \fB\-h\fP
.br
\fI\*(PN\fP \fB\-V\fP

.SH DESCRIPTION
We want to remember which host owns a VCS service group over time, both
to see the current state without a login to the cluster and to associate
system statistics with the correct service groups in the past.  Redundancy
and minimal configuration are desired.  Supplemental statistics such as
number and type of log messages for a group and the time a group came
online are also useful.  Given the infrequency of change in the VCS engine,
a granularity of an hour in data samples is sufficient.
.P
To achieve this, \fI\*(PN\fP, when run, examines the current system and
reports on any groups that are online or partially online that system.
In most cases, no specialized configuration for vcsstats is necessary;
running the command with no options will cause it to read the system and
group configuration from VCS.  As group moves from system to system,
different hosts will report on that group; a system that owns no groups
will generate no reports.  This method provides redundancy, as the
responsability for reporting for a group moves with the group during
failover.
.P
The granularity of the RRD generated by the associated CVU is one
hour.  Oversampling roughly by the natural number, vcsstats should be
scheduled to run once every 20 minutes. This means changes to group state
might only be visible after a latency of 50 minutes.
.P
Note that it is possible that the system name VCS knows the host by may not
match the operating system's hostname. Some assumtions are made about the VCS
configuration:
.HP
1) The name of each system in the VCS cluster matches the
unqualified hostname of each host.  If this is not the
case, either the \fB\-a\fP or \fB\-s\fP options must be used, otherwise
no groups will ever be found to be running on the current host.
.HP
2) Each system name shares the same alphabetical base and
are differentiated only by their unique numerical suffix.
RRDs can only recieve numerical data, so a numerical suffix is
used to identify the system in the update to PEG. If the systems
do not have unique numerical suffixes, \fB\-l\fP must be specified
to read a numerical identifier for each system out of
\fB/etc/llthosts\fP.
.PP
It is strongly reccomended, when setting up a VCS cluster, that each VCS
system name always match the unqualified hostname and that each hostname
share the same alphabetial base followed by a unique numerical suffix.

.SH OPTIONS
.TP
\fB\-a\fP
Report on service groups running on all systems in the cluster.
With this, one system in the cluster can send updates for all
service groups.  This is not reccomended, as it does not
provide adequite redundancy by itself.
.TP
\fB\-l\fP \fI\fP
Read the unique numerical mapping for each system from /etc/llthosts
rather than deriving it from a numerical suffix on the system name.
This should always work as such a mapping must exist for VCS to work.
However, the mapping may not be intuative to users as it is only
meant used internally by LLT and GAB.
.TP
\fB\-N\fP \fInode\fP
Use this node name, rather than our hostname whittled.
This is useful when the hostname of the current host is wrong or unqualified.
.TP
\fB\-s\fP \fIsystem\fP
Report on groups on a particular system.  This matches the system
name within the VCS configuration, not the hostname. If left
unspecified, the unqualified hostname of the current host will be
used as the system name.
.TP
\fB\-t\fP \fItarget\fP
Address and port of an PEG listerner to send updates to.
.TP
\fB\-x\fP
Trace the data from the RRD updates to standard error.
.TP
\fB-h
Print a usage message.
.TP
\fB-V
Show version info and configuration.
.TP
\fIgroup\fP
Report only on specific service groups.  The groups must be owned
by one of the selected systems or no RRD update for those groups
will be generated.

.SH "DEPENDENCIES AND ENVIRONMENT"

.P
This tool has been tested with Veritas Cluster Server 4.1.

.P
Note that vcsstats will augment its PATH with /usr/local/bin automatically
to find these tools. Any one of these defaults can be overriden by setting
the indicated environment variable.

.ta 3.1i
.TP
.nf
op vcs-display grp	VS_DGRPS_COMM
.TP
.nf
op vcs-display res	VS_DRES_COMM
.fi
Vcsstats must be able to read the output of \fBhagrp \-display\fP and
\fBhares \-display\fP, as these commands require root privleges and
vcsstats should not be run as root, vcsstats defaults to use of
the \fBop\fP(1l) rule \fBvcs-display\fP to retrieve this information.

.TP
.nf
since	VS_SINCE_COMM
.fi
The log file is read via the since tool so that only additions
since the last run are processed.

.TP
.nf
rrdup	VS_RRDUP_COMM
.fi
Updates to peg are formatted by rrdup which will take the
responsability of sending the update over the network.

.TP
.nf
/var/VRTSvcs/log/engine_A.log	VS_ENGINE_LOG
.fi
Events that are specific to a running group will be counted and
associated with the system that generated. A tally of each message
type from the logs is sent in the update. Also, the time a group
came fully online is determined from this log.

.TP
.nf
/etc/llthosts	VS_LLTHOSTS
.fi
This is used only with the \fB\-l\fP option when a unique numerical
identifier for a host can not be determined from the system name.

.TP
.nf
$HOME/.vcsstats	VS_STATE_DIR
.fi
Any persistent state needed by vcsstats wull be kept in this
directory that is automatically created when the tool is run.

.TP
.nf
$VS_STATE_DIR/since	VS_SINCE_DB
.fi
A dedicated since database file will be used when reading logs.

.TP
.nf
$VS_STATE_DIR/state	VS_STATE_FILE
.fi
Certain data that can not be easily determined with each run of
the tool, such as online time, will is kept here. This file is
evaled directly into the running \fI\*(PN\fP.
.TA
\".SH EXAMPLES
\".TP
.SH BUGS

.P
The \fBsince\fP operation is not atomic with the RRD update.  While effort is
made to minimize the risk, it is possible for vcsstats to fail for some
reason after since has updated the timestamp in its database, but before
the update is sent.  Also, because the update is a single UDP datagram, it
may be dropped from the network.  In either case, data from the VCS log
will be lost.
.P
Killing a running vcsstats may cause a disconnection warning in the VCS
engine log that will be picked up by monitoring tools such as logsurfer
or OVO.  Such a warning is innocuous and may be ignored.

.SH "SEE ALSO"
sh(1), rrdup(1l), haveip(1l), hagrp(8), hares(8), op(1l)
